@@ -923,7 +923,10 @@ QWebEnginePage::QWebEnginePage(QObject* parent)
     \property QWebEnginePage::contentsSize
     \since 5.7
 
-    \brief The size of the page contents.
+    The size of the full page contents, measured in logical pixels. On devices with a
+    scale factor other than 100%, this will not correspond to the on-screen size; instead,
+    it will be the size before scaling is applied. In such cases, the size may contain
+    fractional values.
 */
 
 /*!
@@ -942,11 +945,11 @@ QWebEnginePage::QWebEnginePage(QObject* parent)
     audio being played or stopped.
 
     \note The signal is also emitted when the \l audioMuted property changes.
-    Also, if the audio is paused this signal is emitted with an approximate \b{two-second
+    Also, if the audio is paused, this signal is emitted with an approximate \b{two-second
     delay} from the moment the audio is paused.
 
     If a web page contains two videos that are started in sequence, this signal
-    gets emitted only once, for the first video to generate sound. After both
+    gets emitted only once for the first video to generate sound. After both
     videos are stopped, the signal is emitted upon the last sound generated.
     This means that the signal is emitted both when any kind of sound is
     generated and when everything is completely silent within a web page,
