@@ -1,5 +1,6 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:critical reason:network-protocol
 
 #include "content_browser_client_qt.h"
 
@@ -893,7 +894,7 @@ std::vector<std::unique_ptr<content::NavigationThrottle>> ContentBrowserClientQt
     throttles.push_back(
             std::make_unique<pdf::PdfNavigationThrottle>(
                 navigation_handle, std::make_unique<PdfStreamDelegateQt>()));
-#endif // BUILDFLAG(ENABLE_PDF) && BUIDLFLAG(ENABLE_EXTENSIONS)
+#endif // BUILDFLAG(ENABLE_PDF) && BUILDFLAG(ENABLE_EXTENSIONS)
 
     return throttles;
 }
@@ -1299,7 +1300,7 @@ ContentBrowserClientQt::WillCreateURLLoaderRequestInterceptors(
         if (pdf_interceptor)
             interceptors.push_back(std::move(pdf_interceptor));
     }
-#endif // BUILDFLAG(ENABLE_PDF) && BUIDLFLAG(ENABLE_EXTENSIONS)
+#endif // BUILDFLAG(ENABLE_PDF) && BUILDFLAG(ENABLE_EXTENSIONS)
 
     return interceptors;
 }
